@@ -15,31 +15,31 @@
 #'
 #' @examples \dontrun{
 #' # Gets all datasets of type "OCCURRENCE".
-#' dataset_search(type="OCCURRENCE")
+#' dataset_search(type="OCCURRENCE", limit = 10)
 #'
 #' # Gets all datasets tagged with keyword "france".
-#' dataset_search(keyword="france")
+#' dataset_search(keyword="france", limit = 10)
 #'
 #' # Fulltext search for all datasets having the word "amsterdam" somewhere in
 #' # its metadata (title, description, etc).
-#' dataset_search(query="amsterdam")
+#' dataset_search(query="amsterdam", limit = 10)
 #'
 #' # Limited search
 #' dataset_search(type="OCCURRENCE", limit=2)
 #' dataset_search(type="OCCURRENCE", limit=2, start=10)
 #'
 #' # Return just descriptions
-#' dataset_search(type="OCCURRENCE", return="descriptions")
+#' dataset_search(type="OCCURRENCE", return="descriptions", limit = 10)
 #'
 #' # Return metadata in a more human readable way (hard to manipulate though)
-#' dataset_search(type="OCCURRENCE", pretty=TRUE)
+#' dataset_search(type="OCCURRENCE", pretty=TRUE, limit = 10)
 #'
 #' # Search by country code. Lookup isocodes first, and use US for United States
 #' isocodes[agrep("UNITED", isocodes$gbif_name),]
-#' dataset_search(country="US")
+#' dataset_search(country="US", limit = 10)
 #'
 #' # Search by decade
-#' dataset_search(decade=1980)
+#' dataset_search(decade=1980, limit = 10)
 #'
 #' # Faceting
 #' ## just facets
@@ -58,12 +58,15 @@ dataset_search <- function(query = NULL, country = NULL, type = NULL, keyword =
   decade = NULL, facet=NULL, facetMincount=NULL, facetMultiselect=NULL, limit=100,
   start=NULL, pretty=FALSE, return="all", ...)
 {
-  if(!is.null(facetMincount) && inherits(facetMincount, "numeric"))
-    stop("Make sure facetMincount is character")
-  if(!is.null(facet)) {
+  if (!is.null(facetMincount) && inherits(facetMincount, "numeric")) {
+    stop("Make sure facetMincount is character", call. = FALSE)
+  }
+  if (!is.null(facet)) {
     facetbyname <- facet
     names(facetbyname) <- rep('facet', length(facet))
-  } else { facetbyname <- NULL }
+  } else {
+    facetbyname <- NULL
+  }
 
   url <- paste0(gbif_base(), '/dataset/search')
   args <- as.list(rgbif_compact(c(q=query,type=type,keyword=keyword,owningOrg=owningOrg,
@@ -78,34 +81,33 @@ dataset_search <- function(query = NULL, country = NULL, type = NULL, keyword =
   meta <- tt[c('offset','limit','endOfRecords','count')]
 
   # if pretty
-  if(pretty){
-    if(length(tt$results)==1){
+  if (pretty) {
+    if (length(tt$results) == 1) {
       printdata(tt$results)
-    } else
-    {
+    } else {
       lapply(tt$results, printdata)[[1]]
     }
-  } else
-  {
+  } else {
     # facets
     facets <- tt$facets
-    if(!length(facets) == 0){
-      facetsdat <- lapply(facets, function(x) do.call(rbind, lapply(x$counts, data.frame, stringsAsFactors=FALSE)))
+    if (!length(facets) == 0) {
+      facetsdat <- lapply(facets, function(x) do.call(rbind, lapply(x$counts, data.frame, stringsAsFactors = FALSE)))
       names(facetsdat) <- facet
-    } else { facetsdat <- NULL  }
+    } else {
+      facetsdat <- NULL
+    }
 
     # descriptions
     descs <- lapply(tt$results, "[[", "description")
     names(descs) <- sapply(tt$results, "[[", "title")
 
     # data
-    if(length(tt$results)==0){
+    if (length(tt$results) == 0) {
       out <- "no results"
-    } else if(length(tt$results)==1){
-      out <- parse_dataset(x=tt$results)
-    } else
-    {
-      out <- do.call(rbind_fill, lapply(tt$results, parse_dataset))
+    } else if (length(tt$results) == 1) {
+      out <- parse_dataset(x = tt$results)
+    } else {
+      out <- tibble::as_data_frame(do.call(rbind_fill, lapply(tt$results, parse_dataset)))
     }
 
     # select output
@@ -115,7 +117,7 @@ dataset_search <- function(query = NULL, country = NULL, type = NULL, keyword =
            descriptions = descs,
            data = out,
            facets = facetsdat,
-           all = list(meta=data.frame(meta), data=out, facets=facetsdat, descriptions=descs))
+           all = list(meta = data.frame(meta), data = out, facets = facetsdat, descriptions = descs))
   }
 }
 
@@ -128,7 +130,7 @@ parse_dataset <- function(x){
                       publishingOrganization=x$publishingOrganizationTitle,
                       publishingOrganizationKey=x$publishingOrganizationKey,
                       publishingCountry=x$publishingCountry))
-  data.frame(tmp, stringsAsFactors=FALSE)
+  data.frame(tmp, stringsAsFactors = FALSE)
 }
 
 printdata <- function(x){
