@@ -82,7 +82,7 @@ occ_data <- function(taxonKey=NULL, scientificName=NULL, country=NULL, publishin
     } else {
       data <- lapply(data, clean_data)
       data <- data.table::setDF(data.table::rbindlist(data, use.names = TRUE, fill = TRUE))
-      data <- prune_result(data)
+      data <- tibble::as_data_frame(prune_result(data))
     }
 
     list(meta = meta, data = data)
@@ -125,16 +125,18 @@ print.gbif_data <- function(x, ..., n = 10) {
     cat(rgbif_wrap(sprintf("Records found [%s]", x$meta$count)), "\n")
     cat(rgbif_wrap(sprintf("Records returned [%s]", NROW(x$data))), "\n")
     cat(rgbif_wrap(sprintf("Args [%s]", pasteargs(x))), "\n")
-    cat(sprintf("First 10 rows of data\n\n"))
-    if (is(x$data, "data.frame")) trunc_mat(x$data, n = n) else cat(x$data)
+    #cat(sprintf("First 10 rows of data\n\n"))
+    # if (inherits(x$data, "data.frame")) trunc_mat(x$data, n = n) else cat(x$data)
+    if (inherits(x$data, "data.frame")) print(x$data) else cat(x$data)
   } else if (attr(x, "type") == "many") {
     cat(rgbif_wrap(sprintf("Occ. found [%s]", pastemax(x))), "\n")
     cat(rgbif_wrap(sprintf("Occ. returned [%s]", pastemax(x, "returned"))), "\n")
     cat(rgbif_wrap(sprintf("Args [%s]", pasteargs(x))), "\n")
     cat(sprintf("First 10 rows of data from %s\n\n", substring(names(x)[1], 1, 50)))
-    if (is(x[[1]]$data, "data.frame")) trunc_mat(x[[1]]$data, n = n) else cat(x[[1]]$data)
+    # if (inherits(x[[1]]$data, "data.frame")) trunc_mat(x[[1]]$data, n = n) else cat(x[[1]]$data)
+    if (inherits(x[[1]]$data, "data.frame")) print(x[[1]]$data) else cat(x[[1]]$data)
   } else {
-    if (is(x, "gbif_data")) x <- unclass(x)
+    if (inherits(x, "gbif_data")) x <- unclass(x)
     attr(x, "type") <- NULL
     attr(x, "return") <- NULL
     print(x)
