@@ -19,7 +19,7 @@ test_that("enumeration", {
 
 test_that("fails correctly", {
   skip_on_cran()
-  
+
   expect_error(enumeration("asdfadsf"), "Status: 204 - not found")
-  expect_error(enumeration_country("asdfadsf"), "no applicable method for 'as.request'")
+  expect_error(enumeration_country("asdfadsf"), "is\\.request\\(y\\) is not TRUE")
 })
