@@ -16,7 +16,7 @@ test_that("returns the correct class", {
   expect_is(tt$data$name, "character")
   expect_is(vv, "data.frame")
   # meta no longer has gbif class
-  expect_equal(length(class(vv)), 1)
+  expect_equal(length(class(vv)), 3)
 
   expect_equal(tt$meta$limit, 2)
   expect_equal(tt$hierarchy[[1]][1,2], 6)
@@ -40,7 +40,7 @@ test_that("returns the correct dimensions", {
   # returns the correct class
   expect_is(out, "data.frame")
   # dimensions
-  expect_equal(dim(out), c(177,42))
+  expect_equal(dim(out), c(177,44))
 })
 
 ## Search by catalog number
@@ -66,8 +66,10 @@ test_that("returns the correct class", {
 
   out <- occ_search(taxonKey=key, return='data')
   expect_is(out, "data.frame")
-  expect_is(out[1,1], "character")
-  expect_is(out[1,2], "integer")
+  expect_is(out, "tbl_df")
+  expect_is(out[1,1], "tbl_df")
+  expect_is(out[1,1]$name, "character")
+  expect_is(out[1,2]$key, "integer")
 
   # returns the correct value
   expect_equal(as.character(out[1,1]), "Helianthus annuus")
@@ -144,7 +146,7 @@ test_that("looping works correctly", {
   allkeys <- unlist(lapply(out, "[[", "key"))
 
   expect_equal(length(allkeys), length(unique(allkeys)))
-  expect_equal(unique(sapply(out, class)), "data.frame")
+  expect_equal(unique(sapply(out, function(x) class(x)[1])), "tbl_df")
 })
 
 ######### scientificName usage works correctly
@@ -154,14 +156,14 @@ test_that("scientificName basic use works - no synonyms", {
   # with synonyms
   bb <- suppressMessages(occ_search(scientificName = 'Pulsatilla patens', limit = 2))
   expect_equal(attr(bb, "args")$scientificName, "Pulsatilla patens")
-  expect_equal(bb$data$name[1], "Anemone patens")
+  expect_equal(bb$data$name[1], "Pulsatilla patens")
 
   # Genus is a synonym - subspecies rank input
   cc <- suppressMessages(occ_search(scientificName = 'Corynorhinus townsendii ingens', limit = 2))
   expect_is(cc, "gbif")
   expect_is(cc$data, "data.frame")
   expect_equal(attr(cc, "args")$scientificName, "Corynorhinus townsendii ingens")
-  expect_equal(cc$data$name[1], "Plecotus townsendii")
+  expect_equal(cc$data$name[1], "Corynorhinus townsendii")
 
   # Genus is a synonym - species rank input
   dd <- suppressMessages(occ_search(scientificName = 'Corynorhinus townsendii', limit = 2))
@@ -169,7 +171,7 @@ test_that("scientificName basic use works - no synonyms", {
   expect_is(dd$data, "data.frame")
   expect_equal(NROW(dd$data), 2)
   expect_equal(attr(dd, "args")$scientificName, "Corynorhinus townsendii")
-  expect_equal(dd$data$name[1], "Plecotus townsendii")
+  expect_equal(dd$data$name[1], "Corynorhinus townsendii")
 
   # specific epithet is the synonym - subspecies rank input
   ee <- suppressMessages(occ_search(scientificName = "Myotis septentrionalis septentrionalis", limit = 2))
@@ -182,19 +184,19 @@ test_that("scientificName basic use works - no synonyms", {
   expect_is(ff, "gbif")
   expect_equal(NROW(ff$data), 2)
   expect_equal(attr(ff, "args")$scientificName, "Myotis septentrionalis")
-  expect_equal(ff$data$name[1], "Myotis keenii")
+  expect_equal(ff$data$name[1], "Myotis septentrionalis")
 
   # Genus is a synonym - species rank input - species not found, so Genus rank given back
   gg <- suppressMessages(occ_search(scientificName = 'Parastrellus hesperus', limit = 2))
   expect_is(gg, "gbif")
-  expect_is(gg$data, "character")
+  expect_is(gg$data, "data.frame")
   ## above not found, but found after using name_lookup to find a match, genus wrong in this case
   # name_lookup(query = 'Parastrellus hesperus')
   hh <- suppressMessages(occ_search(scientificName = 'Pipistrellus hesperus', limit = 2))
   expect_is(hh, "gbif")
   expect_is(hh$data, "data.frame")
   expect_equal(attr(hh, "args")$scientificName, "Pipistrellus hesperus")
-  expect_equal(hh$data$name[1], "Pipistrellus hesperus")
+  expect_equal(hh$data$name[1], "Parastrellus hesperus")
 })
 
 
@@ -261,7 +263,7 @@ test_that("geometry inputs work as expected", {
   wkt <- gsub("\n", " ", wkt)
 
   # Default option with large WKT string fails
-  # expect_error(occ_search(geometry = wkt),
+  # expect_error(occ_search(geometry = wkt, limit = 1),
   #              "Client error: \\(413\\) Request Entity Too Large")
 
   # if WKT too long, with 'geom_big=bbox': makes into bounding box
